/*
 * net.h
 *
 * Header file for the network routines.
 *
 * Kekoa Proudfoot 12/31/96
 */

#ifndef NET_H_DEFINED
#define NET_H_DEFINED

/*****************************************************************************
 * Include files
 *****************************************************************************/

#include <sys/types.h>
#ifdef WIN32
#include <windows.h>
#else
#include <netinet/in.h>
#endif

#include "packet.h"

/*****************************************************************************
 * Interface function declarations
 *****************************************************************************/

extern void net_init               (void);
extern void net_listen             (int s);
extern void net_open_fd            (int s);
extern int  net_open_socket        (int type);
extern void net_close_socket       (int s);
extern void net_connect_socket     (int s, struct sockaddr_in *a, short p);
extern void net_bind_socket        (int s, struct sockaddr_in *a, short p);
extern void net_bind_socket_random (int s, struct sockaddr_in *a, short *p);

extern int  net_check_for_input    (int s);
extern int  net_wait_for_input     (int s, float t);
extern int  net_wait_for_any_input (float t);
extern void net_set_fds(int stdin_fds, int server_socket);

extern int  net_send               (int s, packet_t *p);
extern int  net_recv               (int s, packet_t *p);
extern void net_send_to            (int s, struct sockaddr_in *a, packet_t *p);
extern void net_recv_from          (int s, struct sockaddr_in *a, packet_t *p);

extern char               *net_address_to_name (struct sockaddr_in *a);
extern struct sockaddr_in  net_name_to_address (char *name);
extern char               *net_name_to_numbers (char *name);

#endif
